nxp-pac

Crates

git

Versions

mimxrt1062

Flavors

Tst

Enum Tst 

#[repr(u8)]
pub enum Tst { DIS = 0, EN = 1, EN_LOW = 2, EN_HIGH = 3, }

Variants



DIS = 0

Watchdog test mode disabled.



EN = 1

Watchdog user mode enabled. (Watchdog test mode disabled.) After testing the watchdog, software should use this setting to indicate that the watchdog is functioning normally in user mode.



EN_LOW = 2

Watchdog test mode enabled, only the low byte is used. CNT[CNTLOW] is compared with TOVAL[TOVALLOW].



EN_HIGH = 3

Watchdog test mode enabled, only the high byte is used. CNT[CNTHIGH] is compared with TOVAL[TOVALHIGH].

Implementations

Source

impl Tst

pub const fn from_bits(val: u8) -> Tst

pub const fn to_bits(self) -> u8